==> khttrack-0.10.tar.bz2: khttrack-0.10/khttrack/khttrackview.cpp <==
/***************************************************************************
                          khttrackview.cpp  -  description
                             -------------------
    begin                : lun jun 10 19:13:24 CEST 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly@ifrance.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// include files for Qt
#include <qprinter.h>
#include <qpainter.h>

// application specific includes
#include "khttrackview.h"
#include "khttrackdoc.h"
#include "khttrack.h"

KhttrackView::KhttrackView(QWidget *parent, const char *name) : QWidget(parent, name)
{
  setBackgroundMode(PaletteBase);

}

KhttrackView::~KhttrackView()
{
}

KhttrackDoc *KhttrackView::getDocument() const
{
  KhttrackApp *theApp=(KhttrackApp *) parentWidget();

  return theApp->getDocument();
}

void KhttrackView::print(QPrinter *pPrinter)
{
  QPainter printpainter;
  printpainter.begin(pPrinter);
	
  // TODO: add your printing code here

  printpainter.end();
}

==> khttrack-0.11.tar.bz2: khttrack-0.11/khttrack/khttrackview.cpp <==
/***************************************************************************
                          khttrackview.cpp  -  description
                             -------------------
    begin                : lun jun 10 19:13:24 CEST 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly-devel@laposte.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// include files for Qt
#include <qprinter.h>
#include <qpainter.h>

// application specific includes
#include "khttrackview.h"
#include "khttrackdoc.h"
#include "khttrack.h"

KhttrackView::KhttrackView(QWidget *parent, const char *name) : QWidget(parent, name)
{
  setBackgroundMode(PaletteBase);

}

KhttrackView::~KhttrackView()
{
}

KhttrackDoc *KhttrackView::getDocument() const
{
  KhttrackApp *theApp=(KhttrackApp *) parentWidget();

  return theApp->getDocument();
}

void KhttrackView::print(QPrinter *pPrinter)
{
  QPainter printpainter;
  printpainter.begin(pPrinter);
	
  // TODO: add your printing code here

  printpainter.end();
}
